==> docs_sdk_archive_luna-sdk_droid_complete_rel_v.4.9.0.zip: docs_sdk_archive_luna-sdk_droid_complete_rel_v.4.9.0/doc/fsdk/html/dir_f55a93227fda83d5dd4a3d796702467d.js <==
var dir_f55a93227fda83d5dd4a3d796702467d =
[
    [ "Estimators", "dir_96470401125dcf7b94020a7d1057712f.html", "dir_96470401125dcf7b94020a7d1057712f" ],
    [ "Types", "dir_104afe3ef84f31716f380b8a9fe62f28.html", "dir_104afe3ef84f31716f380b8a9fe62f28" ],
    [ "Def.h", "_def_8h.html", "_def_8h" ],
    [ "Face.h", "_face_8h_source.html", null ],
    [ "FaceEngine.h", "_face_engine_8h.html", "_face_engine_8h" ],
    [ "FSDKError.h", "_f_s_d_k_error_8h.html", "_f_s_d_k_error_8h" ],
    [ "FSDKVersion.h", "_f_s_d_k_version_8h_source.html", null ],
    [ "Human.h", "_human_8h_source.html", null ],
    [ "IAsyncContext.h", "_i_async_context_8h.html", [
      [ "IAsyncContext", "structfsdk_1_1_i_async_context.html", "structfsdk_1_1_i_async_context" ]
    ] ],
    [ "IDescriptor.h", "_i_descriptor_8h.html", "_i_descriptor_8h" ],
    [ "IDetector.h", "_i_detector_8h.html", "_i_detector_8h" ],
    [ "IFaceEngineMobile.h", "_i_face_engine_mobile_8h_source.html", null ],
    [ "IHumanWarper.h", "_i_human_warper_8h.html", [
      [ "IHumanWarper", "structfsdk_1_1_i_human_warper.html", "structfsdk_1_1_i_human_warper" ]
    ] ],
    [ "IIndex.h", "_i_index_8h_source.html", null ],
    [ "ILicense.h", "_i_license_8h_source.html", null ],
    [ "IObject.h", "_i_object_8h.html", null ],
    [ "IRefCounted.h", "_i_ref_counted_8h.html", null ],
    [ "IResultBatch.h", "_i_result_batch_8h_source.html", null ],
    [ "ISettingsProvider.h", "_i_settings_provider_8h.html", "_i_settings_provider_8h" ],
    [ "IWarper.h", "_i_warper_8h.html", [
      [ "Transformation", "structfsdk_1_1_transformation.html", "structfsdk_1_1_transformation" ],
      [ "IWarper", "structfsdk_1_1_i_warper.html", "structfsdk_1_1_i_warper" ]
    ] ],
    [ "Log.h", "_log_8h.html", "_log_8h" ],
    [ "Optional.h", "_optional_8h_source.html", null ],
    [ "Types.h", "_types_8h.html", null ],
    [ "Version.h", "_version_8h.html", "_version_8h" ]
];

==> docs_sdk_archive_luna-sdk_droid_complete_rel_v.5.2.0.zip: docs_sdk_archive_luna-sdk_droid_complete_rel_v.5.2.0/doc/fsdk/html/dir_f55a93227fda83d5dd4a3d796702467d.js <==
var dir_f55a93227fda83d5dd4a3d796702467d =
[
    [ "Estimators", "dir_96470401125dcf7b94020a7d1057712f.html", "dir_96470401125dcf7b94020a7d1057712f" ],
    [ "Types", "dir_104afe3ef84f31716f380b8a9fe62f28.html", "dir_104afe3ef84f31716f380b8a9fe62f28" ],
    [ "Def.h", "_def_8h.html", "_def_8h" ],
    [ "FaceEngine.h", "_face_engine_8h.html", "_face_engine_8h" ],
    [ "FSDKError.h", "_f_s_d_k_error_8h.html", "_f_s_d_k_error_8h" ],
    [ "FSDKVersion.h", "_f_s_d_k_version_8h_source.html", null ],
    [ "IAsyncContext.h", "_i_async_context_8h.html", [
      [ "IAsyncContext", "structfsdk_1_1_i_async_context.html", "structfsdk_1_1_i_async_context" ]
    ] ],
    [ "IDescriptor.h", "_i_descriptor_8h.html", "_i_descriptor_8h" ],
    [ "IDetector.h", "_i_detector_8h.html", "_i_detector_8h" ],
    [ "IFaceDetectionBatch.h", "_i_face_detection_batch_8h_source.html", null ],
    [ "IFaceEngineMobile.h", "_i_face_engine_mobile_8h_source.html", null ],
    [ "IHumanDetectionBatch.h", "_i_human_detection_batch_8h_source.html", null ],
    [ "IHumanDetector.h", "_i_human_detector_8h_source.html", null ],
    [ "IHumanWarper.h", "_i_human_warper_8h.html", [
      [ "IHumanWarper", "structfsdk_1_1_i_human_warper.html", "structfsdk_1_1_i_human_warper" ]
    ] ],
    [ "IIndex.h", "_i_index_8h_source.html", null ],
    [ "ILicense.h", "_i_license_8h_source.html", null ],
    [ "IObject.h", "_i_object_8h.html", null ],
    [ "IRefCounted.h", "_i_ref_counted_8h.html", null ],
    [ "IResultBatch.h", "_i_result_batch_8h_source.html", null ],
    [ "ISettingsProvider.h", "_i_settings_provider_8h.html", "_i_settings_provider_8h" ],
    [ "IWarper.h", "_i_warper_8h.html", [
      [ "Transformation", "structfsdk_1_1_transformation.html", "structfsdk_1_1_transformation" ],
      [ "IWarper", "structfsdk_1_1_i_warper.html", "structfsdk_1_1_i_warper" ]
    ] ],
    [ "LaunchOptions.h", "_launch_options_8h_source.html", null ],
    [ "Log.h", "_log_8h.html", "_log_8h" ],
    [ "Optional.h", "_optional_8h_source.html", null ],
    [ "Types.h", "_types_8h.html", null ],
    [ "Version.h", "_version_8h.html", "_version_8h" ]
];
